==> linm-0.7a.tar.gz: linm-0.7a/src/ncurses/mlsmenu.h <==
/******************************************************************************
 *   Copyright (C) 2005 by la9527                                             *
 *                                                                            *
 *  This program is free software; you can redistribute it and/or modify      * 
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  (at your option) any later version.                                       *
 *                                                                            *
 *  This program is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with this program; if not, write to the Free Software               *
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*
 ******************************************************************************/

#ifndef __MLS_MENU_H__
#define __MLS_MENU_H__

#include "dialog_menu.h"
#include "mainframe.h"

namespace MLS {

class MlsMenu:public Menu
{
protected:
	void MenuColorSetting()
	{
		_tColorMenu = g_tColorCfg.GetColorEntry("Func");
		_tColorMenuA = g_tColorCfg.GetColorEntry("FuncA");
	}
	
	void MenuAddCatecory()
	{
		MenuCategory mls("Mls");
			mls.AddItem(gettext("About"), "Cmd_About", false);
			mls.AddItem(gettext("Help"), "Cmd_Help", false);
			mls.AddItem("", "");
			mls.AddItem(gettext("Quit Mls"), "Cmd_Quit");
		AddItem(mls);
	
		MenuCategory run(gettext("Run"));
			run.AddItem(gettext("Run"), "Cmd_Enter");
			run.AddItem(gettext("Run(select)"), "Cmd_Execute", false);
			run.AddItem("", "");
			run.AddItem(gettext("Shell command"), "Cmd_Shell");
			run.AddItem("", "");
			run.AddItem(gettext("View console"), "Cmd_ESC");
		AddItem(run);
	
		MenuCategory files(gettext("File"));
			files.AddItem(gettext("New"), "Cmd_Newfile", false);
			files.AddItem(gettext("Touch File"), "Cmd_Touchfile", false);
			files.AddItem("", "");
			files.AddItem(gettext("CutClip"), "Cmd_CutClip");
			files.AddItem(gettext("CopyClip"), "Cmd_CopyClip");
			files.AddItem(gettext("PasteClip"), "Cmd_PasteClip");
			files.AddItem("", "");
			files.AddItem(gettext("Copy"), "Cmd_Copy", false);
			files.AddItem(gettext("Move"), "Cmd_Move");
			files.AddItem(gettext("Rename"), "Cmd_Rename");
			files.AddItem(gettext("Delete"), "Cmd_Remove");
			files.AddItem(gettext("Chmod"), "Cmd_Chmod", false);
			files.AddItem("", "");
			files.AddItem(gettext("View"), "Cmd_View");
			files.AddItem(gettext("Edit"), "Cmd_Edit");
			files.AddItem(gettext("Size info"), "Cmd_sizeinfo", false);
			files.AddItem(gettext("FileListSave"), "Cmd_Filelist", false);
			//files.AddItem(gettext("FileFind"), "", false);
			files.AddItem("", "");
			files.AddItem(gettext("Select all"), "Cmd_SelectAll");
			files.AddItem(gettext("Invert select"), "Cmd_SelectInvert");
			//files.AddItem(gettext("Select group"), "", false);
		AddItem(files);
	
		MenuCategory dire(gettext("Directory"));
			dire.AddItem("Mcd", "Cmd_MCD");
			dire.AddItem("Qcd", "Cmd_Qcd", false);
			dire.AddItem("", "");
			dire.AddItem(gettext("Mkdir"), "Cmd_Mkdir");
			dire.AddItem(gettext("To parent"), "Cmd_GoParent");
			dire.AddItem(gettext("To root"), "Cmd_GoRoot");
			dire.AddItem(gettext("To home"), "Cmd_GoHome");
			dire.AddItem("", "");
			dire.AddItem(gettext("Back"), "Cmd_Back", false);
			dire.AddItem(gettext("Forward"), "Cmd_Forward", false);
			//dire.AddItem("", "");
			//dire.AddItem(gettext("Properties"), "<properties>", false);
		AddItem(dire);
	
		MenuCategory util(gettext("Util"));
			util.AddItem(gettext("Ftp Connect"), "Cmd_FtpConn");
			util.AddItem(gettext("Ftp Close"), "Cmd_FtpClose");
			util.AddItem("","");
			util.AddItem(gettext("Extract"), "Cmd_Extract");
			util.AddItem("", "");
			util.AddItem(gettext("Compress (tar.gz)"), "Cmd_Targzcomp", false);
			util.AddItem(gettext("Compress (tar.bz2)"), "Cmd_Tarbz2comp", false);
			util.AddItem(gettext("Compress (zip)"), "Cmd_Zipcomp", false);
		AddItem(util);
	
		MenuCategory view(gettext("View"));
			view.AddItem(gettext("Refresh"), "Cmd_Refresh");
			view.AddItem("", "");
			view.AddItem(gettext("Column AUTO"), "Cmd_ColumnAuto");
			view.AddItem("", "");
			view.AddItem(gettext("Column 1"), "Cmd_Column1");
			view.AddItem(gettext("Column 2"), "Cmd_Column2");
			view.AddItem(gettext("Column 3"), "Cmd_Column3");
			view.AddItem(gettext("Column 4"), "Cmd_Column4");
			view.AddItem("", "");
			view.AddItem(gettext("Show/Hide hidden"), "Cmd_HiddenFileView");
			view.AddItem(gettext("Sort Change"), "Cmd_SortChange");
			view.AddItem("", "");
			view.AddItem(gettext("Split"),  "Cmd_Split");
			view.AddItem(gettext("Next window"), "Cmd_NextWindow");
			view.AddItem("", "");
			view.AddItem(gettext("SplitSync On/Off"), "Cmd_SplitViewSync");
			
		AddItem(view);
	
		MenuCategory op(gettext("Option"));
			op.AddItem(gettext("Linecode Change"), "Cmd_BoxCodeChange");
			op.AddItem(gettext("Korean Mode"), "Cmd_LangChange");
			op.AddItem("", "");
			op.AddItem(gettext("Edit Config"), "Cmd_Editconfig", false);
			op.AddItem(gettext("Edit Keybind"), "Cmd_Editkeybind", false);
			op.AddItem(gettext("Edit Colorset"), "Cmd_Editcolorset", false);
		AddItem(op);
	}

	// Reflash 할때 기타 화면을 Reflesh 꼭 넣어야 제대로 화면 나옴.
	void MenuRefresh()
	{
		g_tMainFrame.Refresh(true);
	}

};

};

#endif

==> linm-0.7.5b.tar.gz: linm-0.7.5b/src/ncurses/mlsmenu.h <==
/******************************************************************************
 *   Copyright (C) 2005 by la9527                                             *
 *                                                                            *
 *  This program is free software; you can redistribute it and/or modify      * 
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  (at your option) any later version.                                       *
 *                                                                            *
 *  This program is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with this program; if not, write to the Free Software               *
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*
 ******************************************************************************/

#ifndef __MLS_MENU_H__
#define __MLS_MENU_H__

#include "define.h"
#include "dialog_menu.h"
#include "mainframe.h"

namespace MLS {

class MlsMenu:public Menu
{
protected:
	void MenuColorSetting()
	{
		_tColorMenu = g_tColorCfg.GetColorEntry("Func");
		_tColorMenuA = g_tColorCfg.GetColorEntry("FuncA");
	}

	void MenuAddCatecory()
	{
		MenuCategory mls("LinM", PANEL);
			mls.AddItem(gettext("About"), "Cmd_About");
			mls.AddItem(gettext("Help"), "Cmd_Help", false);
			mls.AddItem("", "");
			mls.AddItem(gettext("Quit LinM"), "Cmd_Quit");
		AddItem(mls);
	
		MenuCategory run(gettext("Run"), PANEL);
			run.AddItem(gettext("Run"), "Cmd_Enter");
			run.AddItem(gettext("Run(select)"), "Cmd_Execute", false);
			run.AddItem("", "");
			run.AddItem(gettext("Shell command"), "Cmd_Shell");
			run.AddItem("", "");
			run.AddItem(gettext("View console"), "Cmd_ESC");
		AddItem(run);
	
		MenuCategory files(gettext("File"), PANEL);
			//files.AddItem(gettext("New"), "Cmd_Newfile", false);
			//files.AddItem(gettext("Touch File"), "Cmd_Touchfile", false);
			//files.AddItem("", "");
			files.AddItem(gettext("CutClip"), "Cmd_CutClip");
			files.AddItem(gettext("CopyClip"), "Cmd_CopyClip");
			files.AddItem(gettext("PasteClip"), "Cmd_PasteClip");
			files.AddItem("", "");
			files.AddItem(gettext("Copy"), "Cmd_Copy");
			files.AddItem(gettext("Move"), "Cmd_Move");
			files.AddItem(gettext("Rename"), "Cmd_Rename");
			files.AddItem(gettext("Delete"), "Cmd_Remove");
			files.AddItem(gettext("Chmod"), "Cmd_Chmod", false);
			files.AddItem("", "");
			files.AddItem(gettext("View"), "Cmd_View");
			files.AddItem(gettext("Edit"), "Cmd_Edit");
			files.AddItem(gettext("Size info"), "Cmd_SizeInfo");
			//files.AddItem(gettext("FileListSave"), "Cmd_Filelist", false);
			//files.AddItem(gettext("FileFind"), "", false);
			files.AddItem("", "");
			files.AddItem(gettext("Select all"), "Cmd_SelectAll");
			files.AddItem(gettext("Invert select"), "Cmd_SelectInvert");
			//files.AddItem(gettext("Select group"), "", false);
		AddItem(files);
	
		MenuCategory dire(gettext("Directory"), PANEL);
			dire.AddItem("Mcd", "Cmd_MCD");
			dire.AddItem("Qcd", "Cmd_Qcd", false);
			dire.AddItem("", "");
			dire.AddItem("Mount List", "Cmd_MountList");
			dire.AddItem("", "");
			dire.AddItem(gettext("Mkdir"), "Cmd_Mkdir");
			dire.AddItem(gettext("To parent"), "Cmd_GoParent");
			dire.AddItem(gettext("To root"), "Cmd_GoRoot");
			dire.AddItem(gettext("To home"), "Cmd_GoHome");
			dire.AddItem("", "");
			dire.AddItem(gettext("Back"), "Cmd_Back", false);
			dire.AddItem(gettext("Forward"), "Cmd_Forward", false);
			//dire.AddItem("", "");
			//dire.AddItem(gettext("Properties"), "<properties>", false);
		AddItem(dire);
	
		MenuCategory util(gettext("Util"), PANEL);
			util.AddItem(gettext("Connect"), "Cmd_RemoteConnect");
			util.AddItem(gettext("Disconnect"), "Cmd_RemoteClose");
			util.AddItem("","");
			util.AddItem(gettext("Extract"), "Cmd_Extract");
			util.AddItem("", "");
			util.AddItem(gettext("Compress (tar.gz)"), "Cmd_Targzcomp", false);
			util.AddItem(gettext("Compress (tar.bz2)"), "Cmd_Tarbz2comp", false);
			util.AddItem(gettext("Compress (zip)"), "Cmd_Zipcomp", false);
		AddItem(util);
	
		MenuCategory view(gettext("View"), PANEL);
			view.AddItem(gettext("Refresh"), "Cmd_Refresh");
			view.AddItem("", "");
			view.AddItem(gettext("Column AUTO"), "Cmd_ColumnAuto");
			view.AddItem("", "");
			view.AddItem(gettext("Column 1"), "Cmd_Column1");
			view.AddItem(gettext("Column 2"), "Cmd_Column2");
			view.AddItem(gettext("Column 3"), "Cmd_Column3");
			view.AddItem(gettext("Column 4"), "Cmd_Column4");
			view.AddItem("", "");
			view.AddItem(gettext("Show/Hide hidden"), "Cmd_HiddenFileView");
			view.AddItem(gettext("Sort Change"), "Cmd_SortChange");
			view.AddItem("", "");
			view.AddItem(gettext("Split"),  "Cmd_Split");
			view.AddItem(gettext("Next window"), "Cmd_NextWindow");
			view.AddItem("", "");
			view.AddItem(gettext("SplitSync On/Off"), "Cmd_SplitViewSync");
			
		AddItem(view);
	
		MenuCategory op(gettext("Option"), PANEL);
			op.AddItem(gettext("Linecode Change"), "Cmd_BoxCodeChange");
			op.AddItem(gettext("Korean Mode"), "Cmd_LangChange");
			op.AddItem("", "");
			op.AddItem(gettext("Edit Config"), "Cmd_DefaultCfgFileChg");
			op.AddItem(gettext("Edit Keybind"), "Cmd_KeyCfgFileChg");
			op.AddItem(gettext("Edit Colorset"), "Cmd_ColorCfgFileChg");
		AddItem(op);
	}
	
	// Reflash 할때 기타 화면을 Reflesh 꼭 넣어야 제대로 화면 나옴.
	void MenuRefresh()
	{
		g_tMainFrame.Refresh(true);
	}

public:
	MlsMenu(): Menu() { }
};

class McdMenu:public Menu
{
protected:
	void MenuColorSetting()
	{
		_tColorMenu = g_tColorCfg.GetColorEntry("Func");
		_tColorMenuA = g_tColorCfg.GetColorEntry("FuncA");
	}

	void MenuAddCatecory()
	{
		MenuCategory mcd("Mcd", MCD);
			mcd.AddItem(gettext("About"), "Cmd_About");
			mcd.AddItem(gettext("Help"), "Cmd_Help", false);
			mcd.AddItem("", "");
			mcd.AddItem(gettext("Quit Mcd"), "Cmd_Quit");
		AddItem(mcd);
	
		MenuCategory dire(gettext("Directory"), MCD);
			dire.AddItem(gettext("Mkdir"), "Cmd_Mkdir");
			dire.AddItem(gettext("Rename"), "Cmd_Rename");
			dire.AddItem("", "");
			dire.AddItem("Mount List", "Cmd_MountList");
			dire.AddItem("Size Info", "Cmd_SizeInfo");
			dire.AddItem("", "");
			dire.AddItem(gettext("CutClip"), "Cmd_CutClip");
			dire.AddItem(gettext("CopyClip"), "Cmd_CopyClip");
			dire.AddItem(gettext("PasteClip"), "Cmd_PasteClip");
			dire.AddItem("", "");
			dire.AddItem(gettext("To parent"), "Cmd_GoParent");
			dire.AddItem(gettext("To root"), "Cmd_GoRoot");
			dire.AddItem(gettext("To home"), "Cmd_GoHome");
		AddItem(dire);
	
		MenuCategory util(gettext("Util"), MCD);
			util.AddItem(gettext("Connect"), "Cmd_RemoteConnect");
			util.AddItem(gettext("Disconnect"), "Cmd_RemoteClose");
		AddItem(util);
	
		MenuCategory view(gettext("View"), MCD);
			view.AddItem(gettext("Refresh"), "Cmd_Refresh");
			view.AddItem("", "");
			view.AddItem(gettext("Show/Hide hidden"), "Cmd_HiddenFileView");
			view.AddItem(gettext("Sort Change"), "Cmd_SortChange");
			view.AddItem("", "");
			view.AddItem(gettext("Split"),  "Cmd_Split");
			view.AddItem(gettext("Next window"), "Cmd_NextWindow");
			view.AddItem("", "");
			view.AddItem(gettext("SplitSync On/Off"), "Cmd_SplitViewSync");
			
		AddItem(view);
	
		MenuCategory op(gettext("Option"), MCD);
			op.AddItem(gettext("Linecode Change"), "Cmd_BoxCodeChange");
			op.AddItem("", "");
			op.AddItem(gettext("Korean Mode"), "Cmd_LangChange");
		AddItem(op);
	}

	// Reflash 할때 기타 화면을 Reflesh 꼭 넣어야 제대로 화면 나옴.
	void MenuRefresh()
	{
		g_tMainFrame.Refresh(true);
	}
public:
	McdMenu(): Menu() {  }
};

class EditorMenu:public Menu
{
private:
	NCurses_Editor*	 _pEditor;

protected:
	void MenuColorSetting()
	{
		_tColorMenu = g_tColorCfg.GetColorEntry("Func");
		_tColorMenuA = g_tColorCfg.GetColorEntry("FuncA");
	}

	void MenuAddCatecory()
	{
		MenuCategory File(gettext("File"), EDITOR );
			File.AddItem(gettext("New"), "Cmd_New");
			File.AddItem("", "");
			File.AddItem(gettext("Save"), "Cmd_Save");
			File.AddItem(gettext("Save As"), "Cmd_SaveAS");
			File.AddItem("", "");
			File.AddItem(gettext("Quit"), "Cmd_Quit");
		AddItem(File);
	
		MenuCategory Edit(gettext("Edit"), EDITOR );
			Edit.AddItem(gettext("Undo"), "Cmd_Undo");
			Edit.AddItem("", "");
			Edit.AddItem(gettext("Cut"), "Cmd_CutClip");
			Edit.AddItem(gettext("Copy"), "Cmd_CopyClip");
			Edit.AddItem(gettext("Paste"), "Cmd_PasteClip");
			Edit.AddItem("", "");
			Edit.AddItem(gettext("Indent"), "Cmd_Tab");
			Edit.AddItem(gettext("Unindent"), "Cmd_Untab");
			Edit.AddItem("", "");
			if (_pEditor && _pEditor->GetIndentMode())
				Edit.AddItem(gettext("Indent Off"), "Cmd_IndentMode");
			else
				Edit.AddItem(gettext("Indent On"), "Cmd_IndentMode");
			Edit.AddItem("", "");
			Edit.AddItem(gettext("Select All"), "Cmd_SelectAll");
			Edit.AddItem("", "");
			Edit.AddItem(gettext("Select Mode"), "Cmd_SelectMode");
		AddItem(Edit);

	    MenuCategory Find(gettext("Find"), EDITOR );
			Find.AddItem(gettext("Find"), "Cmd_Find");
			Find.AddItem("", "");
			Find.AddItem(gettext("Find Next"), "Cmd_FindNext");
			Find.AddItem(gettext("Find Previous"), "Cmd_FindPrevious");
		AddItem(Find);
	
		MenuCategory View(gettext("View"), EDITOR );
			View.AddItem(gettext("Refresh"), "Cmd_Refresh");
			View.AddItem("", "");
			View.AddItem(gettext("Split"),  "Cmd_Split");
			View.AddItem(gettext("Next window"), "Cmd_NextWindow");
			View.AddItem("", "");
			View.AddItem(gettext("Show line numbers"), "Cmd_LineNumberView");
			View.AddItem("", "");
			View.AddItem(gettext("Goto Line"), "Cmd_GotoLine");
			View.AddItem("", "");
			View.AddItem(gettext("Goto First"), "Cmd_GotoFirst");
			View.AddItem(gettext("Goto End"),  "Cmd_GotoEnd");
			View.AddItem("", "");
			View.AddItem(gettext("Vim Editor"),  "Cmd_VimView");
		AddItem(View);

		MenuCategory op(gettext("Option"), EDITOR );
			op.AddItem(gettext("Linecode Change"), "Cmd_BoxCodeChange");
			op.AddItem(gettext("Korean Mode"), "Cmd_LangChange");
		AddItem(op);
	}

	// Reflash 할때 기타 화면을 Reflesh 꼭 넣어야 제대로 화면 나옴.
	void MenuRefresh()
	{
		g_tMainFrame.Refresh(true);
	}

public:
	NCurses_Editor*	SetEditor(NCurses_Editor* p) { _pEditor = p; }
	EditorMenu(): Menu() { _pEditor = NULL; }
};

};

#endif
